@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@
 #include <mia/core/file.hh>
 #include <mia/core/filter.hh>
 #include <mia/core/msgstream.hh>
-#include <mia/core/bfsv23dispatch.hh>
 #include <mia/2d/imageio.hh>
 
 NS_BEGIN(IMAGEIO_3D_DICOM)
@@ -49,11 +48,11 @@ CDicom3DImageIOPlugin::CDicom3DImageIOPlugin():
 	add_supported_type(it_ushort);
 	add_supported_type(it_sshort);
 
-	TTranslator<float>::register_for("SliceLocation");
-	TTranslator<double>::register_for("AcquisitionTime"); 
-	TTranslator<int>::register_for("SeriesNumber");
-	TTranslator<int>::register_for("AcquisitionNumber");
-	TTranslator<int>::register_for("InstanceNumber");
+	CFloatTranslator::register_for("SliceLocation");
+	CDoubleTranslator::register_for("AcquisitionTime"); 
+	CSITranslator::register_for("SeriesNumber");
+	CSITranslator::register_for("AcquisitionNumber");
+	CSITranslator::register_for("InstanceNumber");
 	CPatientPositionTranslator::register_for(IDPatientPosition);
 	add_suffix(".dcm");
 	add_suffix(".DCM");
@@ -213,7 +212,7 @@ static void add_images(const string& fname, const string& study_id, vector<P2DIm
 {
 	TRACE_FUNCTION;
 	bfs::path dir(fname);
-	string ext = __bfs_get_extension(dir);
+	string ext = dir.extension().string();
 	dir.remove_filename();
 
 	if (dir.filename().empty())
@@ -231,8 +230,8 @@ static void add_images(const string& fname, const string& study_id, vector<P2DIm
 	bfs::directory_iterator di(dir);
 	bfs::directory_iterator dend;
 	while (di != dend) {
-		if (boost::regex_match(__bfs_get_filename(di->path()), pat_expr) &&
-		    __bfs_get_filename(di->path()) != fname) {
+		if (boost::regex_match(di->path().filename().string(), pat_expr) &&
+		    di->path().filename().string() != fname) {
 			bfs::path f =  di->path();
 			cvdebug() << "read file '" << f << "'\n";
 			CDicomReader reader(f.string().c_str());
@@ -298,8 +297,8 @@ CSliceSaver::CSliceSaver(const string& fname):
 {
 	// filename split the
 	bfs::path fullname(fname);
-	m_extension = __bfs_get_extension(fullname);
-	m_fnamebase = __bfs_get_stem(fullname);
+	m_extension = fullname.extension().string();
+	m_fnamebase = fullname.stem().string();
 }
 
 void CSliceSaver::set_instance(size_t series, size_t slice)
