@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,8 +37,8 @@ struct PathInitFixture {
 
 PathInitFixture::PathInitFixture()
 {
-	CPathNameArray searchpath;
-	searchpath.push_back(bfs::path("."));
+	CPluginSearchpath searchpath(true);
+	searchpath.add(".");
 
 	C2DImageIOPluginHandler::set_search_path(searchpath);
 	C2DVFIOPluginHandler::set_search_path(searchpath);
