@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -202,7 +202,7 @@ const std::string CVista2DImageIOPlugin::do_get_preferred_suffix() const
 
 extern "C" EXPORT  CPluginBase *get_plugin_interface()
 {
-	TTranslator<C2DFVector>::register_for("pixel");
+	C2DFVectorTranslator::register_for("pixel");
 	return new CVista2DImageIOPlugin();
 }
 
