@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,8 +63,7 @@ C2DKMeansFilterPluginFactory::C2DKMeansFilterPluginFactory():
 	C2DFilterPlugin("kmeans"),
 	m_classes(3)
 {
-	add_parameter("c", new CIntParameter(m_classes, 2, numeric_limits<unsigned char>::max(),
-					     false, "number of classes"));
+	add_parameter("c", make_lc_param(m_classes, 2, false, "number of classes"));
 }
 
 C2DFilter *C2DKMeansFilterPluginFactory::do_create()const
