@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,8 @@ using namespace mlv_2dimage_filter;
 BOOST_AUTO_TEST_CASE( test_mlv )
 {
 #ifndef WIN32
-	srand48(time(NULL));
+	// deterministic test, aleays use the same seed 
+	srand48(0);
 #endif
 
 	for (int width = 2; width < 12; ++width) {
