@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -175,16 +175,11 @@ C2DNavierRegModelPlugin::C2DNavierRegModelPlugin():
 	m_epsilon(0.0001),
 	m_maxiter(100)
 {
-	add_parameter("mu", new CFloatParameter(m_mu, 0.0, numeric_limits<float>::max(),
-							   false, "isotropic compliance"));
-	add_parameter("lambda", new CFloatParameter(m_lambda, 0.0, numeric_limits<float>::max(),
-							       false, "isotropic compression"));
-	add_parameter("omega", new CFloatParameter(m_omega, 0.1, 10,
-							      false, "relexation parameter"));
-	add_parameter("epsilon", new CFloatParameter(m_epsilon, 0.000001, 0.1,
-								false, "stopping parameter"));
-	add_parameter("iter", new CIntParameter(m_maxiter, 10, 10000,
-							   false, "maximum number of iterations"));
+	add_parameter("mu", make_nonnegative_param(m_mu, false, "isotropic compliance"));
+	add_parameter("lambda", make_nonnegative_param(m_lambda, false, "isotropic compression"));
+	add_parameter("omega", make_ci_param(m_omega, 0.1, 10, false, "relexation parameter"));
+	add_parameter("epsilon", make_oci_param(m_epsilon, 0.0, 0.1, false, "stopping parameter"));
+	add_parameter("iter", make_ci_param(m_maxiter, 1, 10000, false, "maximum number of iterations"));
 }
 
 C2DRegModel *C2DNavierRegModelPlugin::do_create()const
