@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -156,9 +156,6 @@ namespace bfs=boost::filesystem;
 
 FixPluginpath::FixPluginpath()
 {
-	CPathNameArray minimizerpath;
-	minimizerpath.push_back(bfs::path("../core/minimizer"));
-	CMinimizerPluginHandler::set_search_path(minimizerpath); 
 }
 
 FixPluginpath PseudoGroundTruthFixture::fix; 
