@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,8 +32,7 @@ using std::numeric_limits;
 C2DRegTimeStep::C2DRegTimeStep(float min, float max):
 	m_min(min),
 	m_max(max),
-	m_current((max - min)/ 2.0 + min ),
-	m_step((max-min) / 20)
+	m_current((max - min)/ 2.0 + min )
 {
 }
 
@@ -87,10 +86,10 @@ C2DRegTimeStepPlugin::C2DRegTimeStepPlugin(const char *name):
 	m_min(0.1),
 	m_max(2.0)
 {
-	add_parameter("min", new CFloatParameter(m_min, 0.001, numeric_limits<float>::max(),
-							   false, "minimum time step allowed"));
-	add_parameter("max", new CFloatParameter(m_max, 0.002, numeric_limits<float>::max(),
-							       false, "maximum time step allowed"));
+	add_parameter("min", new CFBoundedParameter(m_min, EParameterBounds::bf_min_open, {0.0},
+						    false, "minimum time step allowed"));
+	add_parameter("max", new CFBoundedParameter(m_max, EParameterBounds::bf_min_open, {0.0},
+						    false, "maximum time step allowed"));
 }
 
 float C2DRegTimeStepPlugin::get_min_timestep() const
