@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ mia::P3DImage T3DImageCombiner<BO>::operator () ( const T3DImage<T>& a, const T3
 	BO bo; 
 	typedef decltype(bo(a[0], b[0])) R; 
 			
-	auto  r = new T3DImage<R>(a.get_size()); 
+	auto  r = new T3DImage<R>(a.get_size(), a); 
 	
 	P3DImage result(r);
 
