@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 NS_MIA_BEGIN
 
 template <typename T>
-const unsigned int T3DDatafield<T>::m_elements = 
+const size_t T3DDatafield<T>::m_elements = 
 	sizeof(T) / sizeof(typename T3DDatafield<T>::atomic_type); 
 
 template <typename T>
@@ -53,16 +53,16 @@ void T3DDatafield<T>::swap(T3DDatafield& other)
 template <typename T>
 T3DDatafield<T>::T3DDatafield(const C3DBounds& size ):
 	m_size(size),
-	m_xy(size.x * size.y), 
-	m_data(new std::vector<T>(size.x * size.y * size.z))
+	m_xy(static_cast<size_t>(size.x) * static_cast<size_t>(size.y)), 
+	m_data(new std::vector<T>(m_xy * static_cast<size_t>(size.z)))
 {
 }
 
 template <typename T>
 T3DDatafield<T>::T3DDatafield(const C3DBounds& size, const T *data):
 	m_size(size), 
-	m_xy(size.x * size.y), 
-	m_data(new std::vector<T>(size.x * size.y * size.z))
+	m_xy(static_cast<size_t>(size.x) * static_cast<size_t>(size.y)), 
+	m_data(new std::vector<T>(m_xy * static_cast<size_t>(size.z)))
 {
 	std::copy(data, data + m_data->size(), m_data->begin()); 
 }
@@ -141,6 +141,23 @@ T3DDatafield<T>::get_trilin_interpol_val_at(const T3DVector<float >& p) const
         }
 }
 
+
+template <typename T>
+typename T3DDatafield<T>::Range
+T3DDatafield<T>::get_range(const C3DBounds& start, const C3DBounds& end)
+{
+	this->make_single_ref(); 
+	return Range(start, end, *this); 
+}
+
+template <typename T>
+typename T3DDatafield<T>::ConstRange
+T3DDatafield<T>::get_range(const C3DBounds& start, const C3DBounds& end) const
+{
+	return ConstRange(start, end, *this); 
+}
+
+
 template <typename T>
 struct __copy_dispatch {
 	typedef typename atomic_data<T>::type atomic_type; 
@@ -227,7 +244,7 @@ template <typename T>
 void T3DDatafield<T>::get_data_line_x(int y, int z, std::vector<T>& result)const
 {
         result.resize(m_size.x);
-	const int start = m_size.x * (y + z * m_size.y); 
+	const size_t start = m_xy * z + static_cast<size_t>(m_size.x) * y; 
 	__mia_copy_dispatch<T>::apply_read(result, *m_data, start, m_size.x); 
 }
 
@@ -235,9 +252,7 @@ template <typename T>
 void T3DDatafield<T>::get_data_line_y(int x, int z, std::vector<T>& result)const
 {
         result.resize(m_size.y);
-	size_t start = x + m_size.x * m_size.y * z;
-
-	typename std::vector<T>::const_iterator i = m_data->begin() + start; 
+	auto i = m_data->begin() + static_cast<size_t>(x) + m_xy * z; 
 	
 	for (typename std::vector<T>::iterator k = result.begin(); k != result.end(); ++k, i += m_size.x)
                 *k = *i;
@@ -247,7 +262,7 @@ template <typename T>
 void T3DDatafield<T>::get_data_line_z(int x, int y, std::vector<T>& result)const
 {
         result.resize(m_size.z);
-	size_t start = x + m_size.x * y;
+	size_t start = static_cast<size_t>(x) + static_cast<size_t>(m_size.x) * y;
 
 
 	typename std::vector<T>::const_iterator i = m_data->begin() + start;
@@ -637,6 +652,52 @@ T3DDatafield<T>::end_range_with_boundary_flags(const C3DBounds& begin, const C3D
 }
 
 
+template <typename T>
+typename T3DDatafield<T>::Range::iterator T3DDatafield<T>::Range::begin()
+{
+	return m_begin; 
+}
+
+template <typename T>
+typename T3DDatafield<T>::Range::iterator T3DDatafield<T>::Range::end()
+{
+	return m_end; 
+}
+
+template <typename T>
+T3DDatafield<T>::Range::Range(const C3DBounds& start, const C3DBounds& end, T3DDatafield<T>& field):
+	m_begin(field.begin_range(start, end)), m_end(field.end_range(start, end))
+{
+}
+					    
+
+template <typename T>
+typename T3DDatafield<T>::ConstRange::iterator T3DDatafield<T>::ConstRange::begin() const 
+{
+	return m_begin; 
+}
+
+template <typename T>
+typename T3DDatafield<T>::ConstRange::iterator T3DDatafield<T>::ConstRange::end() const 
+{
+	return m_end; 
+}
+
+
+template <typename T>
+T3DDatafield<T>::ConstRange::ConstRange(const C3DBounds& start, const C3DBounds& end, const T3DDatafield<T>& field):
+	m_begin(field.begin_range(start, end)), m_end(field.end_range(start, end))
+{
+}
+
+template <typename T>
+T3DDatafield<T>::ConstRange::ConstRange(const Range& range):
+	m_begin(range.m_begin), m_end(range.m_end)
+{
+}
+
+
+
 NS_MIA_END
 
 #endif
