@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,9 +37,6 @@ struct MorpologicalFilter_Fixture: public fifof_Fixture  {
 
 MorpologicalFilter_Fixture::MorpologicalFilter_Fixture()
 {
-	CPathNameArray searchpath;
-	searchpath.push_back(bfs::path("..")/bfs::path("shapes"));
-	C3DShapePluginHandler::set_search_path(searchpath);
 	m_shape = C3DShapePluginHandler::instance().produce("6n");
 }
 
