@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,9 +28,6 @@ NS_MIA_USE;
 
 struct RegiongrowFixture: public fifof_Fixture {
 	RegiongrowFixture() {
-		CPathNameArray searchpath;
-		searchpath.push_back(bfs::path("..")/bfs::path("shapes"));
-		C3DShapePluginHandler::set_search_path(searchpath);
 	}
 };
 
