@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -105,17 +105,11 @@ C3DDownscaleFilterPlugin::C3DDownscaleFilterPlugin():
 	m_b(1,1,1), 
 	m_filter("gauss")
 {
-	add_parameter("bx", new CUIntParameter(m_b.x, 1,
-					       numeric_limits<int>::max(), false,
-					       "blocksize in x direction"));
+	add_parameter("bx", make_lc_param(m_b.x, 1, false, "blocksize in x direction"));
 	
-	add_parameter("by", new CUIntParameter(m_b.y, 1,
-					       numeric_limits<int>::max(), false,
-					       "blocksize in y direction"));
+	add_parameter("by", make_lc_param(m_b.y, 1,false, "blocksize in y direction"));
 	
-	add_parameter("bz", new CUIntParameter(m_b.z, 1,
-					       numeric_limits<int>::max(), false,
-                                                "blocksize in z direction"));
+	add_parameter("bz", make_lc_param(m_b.z, 1, false, "blocksize in z direction"));
 
 	add_parameter("b", new C3DBoundsParameter(m_b, false, "blocksize"));
 
