@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,10 +44,6 @@ C3DReorient::result_type C3DReorient::operator () (const mia::T3DImage<T>& data)
 
 	EOrientations strategy = m_strategy;
 
-	if (strategy == axial ||  strategy == coronal || strategy == saggital) {
-		strategy = get_strategy(data.get_orientation());
-	}
-
 	cvdebug() << "strategy = " << strategy << "(" << m_strategy <<")\n";
 	switch (strategy) {
 	case xyz: {
@@ -55,7 +51,7 @@ C3DReorient::result_type C3DReorient::operator () (const mia::T3DImage<T>& data)
 		copy(data.begin(), data.end(), result->begin());
 		break;
 	}
-	case xzy: {
+	case flip_yz: {
 		C3DBounds out_size(data.get_size().xzy() );
 		result = new T3DImage<T>(out_size, data);
 		result->set_voxel_size(data.get_voxel_size().xzy());
@@ -67,7 +63,7 @@ C3DReorient::result_type C3DReorient::operator () (const mia::T3DImage<T>& data)
 		}
 		break;
 	}
-	case yxz: {
+	case flip_xy: {
 		C3DBounds out_size(data.get_size().yxz() );
 		result = new T3DImage<T>(out_size, data);
 		result->set_voxel_size(data.get_voxel_size().yxz());
@@ -106,7 +102,7 @@ C3DReorient::result_type C3DReorient::operator () (const mia::T3DImage<T>& data)
 		}
 		break;
 	}
-	case zyx: {
+	case flip_xz: {
 		C3DBounds out_size(data.get_size().zyx() );
 		result = new T3DImage<T>(out_size, data);
 		result->set_voxel_size(data.get_voxel_size().zyx());
@@ -119,6 +115,149 @@ C3DReorient::result_type C3DReorient::operator () (const mia::T3DImage<T>& data)
 		}
 		break;
 	}
+	case rotate_x90:{
+		// rotate around x-axis by 90 degree 
+		C3DBounds out_size(data.get_size().yxz() );
+		result = new T3DImage<T>(out_size, data);
+		result->set_voxel_size(data.get_voxel_size().yxz());
+		for (size_t z = 0; z < data.get_size().z; ++z) {
+			for (size_t y = 0; y < data.get_size().y; ++y) {
+				copy(data.begin_at(0,y,z), data.begin_at(0,y,z) + data.get_size().x,
+				     result->begin_at(0,result->get_size().z - z - 1,y));
+			}
+		}
+		break;
+	}
+	case rotate_x180:{
+		// rotate around x-axis by 180 degree 
+		C3DBounds out_size(data.get_size());
+		result = new T3DImage<T>(out_size, data);
+		result->set_voxel_size(data.get_voxel_size());
+		for (size_t z = 0; z < data.get_size().z; ++z) {
+			for (size_t y = 0; y < data.get_size().y; ++y) {
+				copy(data.begin_at(0,y,z), data.begin_at(0,y,z) + data.get_size().x,
+				     result->begin_at(0,result->get_size().y - 1 - y,
+						      result->get_size().z - 1 - z));
+			}
+		}
+		break;
+	}
+	case rotate_x270:{
+		// rotate around x-axis by 270 degree 
+		C3DBounds out_size(data.get_size().yxz() );
+		result = new T3DImage<T>(out_size, data);
+		result->set_voxel_size(data.get_voxel_size().yxz());
+		for (size_t z = 0; z < data.get_size().z; ++z) {
+			for (size_t y = 0; y < data.get_size().y; ++y) {
+				copy(data.begin_at(0,y,z), data.begin_at(0,y,z) + data.get_size().x,
+				     result->begin_at(0,z,result->get_size().y - 1 - y));
+			}
+		}
+		break;
+	}
+	case rotate_y90:{
+		// rotate around y-axis by 90 degree clock wise
+		
+		C3DBounds out_size(data.get_size().zyx());
+		result = new T3DImage<T>(out_size, data);
+		result->set_voxel_size(data.get_voxel_size().zyx());
+
+		unsigned  oz = data.get_size().z - 1; 
+		for (size_t z = 0; z < data.get_size().z; ++z, --oz) {
+			for (size_t y = 0; y < data.get_size().y; ++y) {
+				for (size_t x = 0; x < data.get_size().x; ++x) {
+					(*result)(oz,y,x) = data(x,y,z);
+				}
+			}
+		}
+		break;
+	}
+	case rotate_y180:{
+		// rotate around y-axis by 180 degree 
+		C3DBounds out_size(data.get_size());
+		result = new T3DImage<T>(out_size, data);
+		result->set_voxel_size(data.get_voxel_size());
+		
+		unsigned  oz = data.get_size().z - 1; 
+		for (size_t z = 0; z < data.get_size().z; ++z, --oz) {
+			for (size_t y = 0; y < data.get_size().y; ++y) {
+				unsigned ox = data.get_size().x - 1; 
+				for (size_t x = 0; x < data.get_size().x; ++x, --ox) {
+					(*result)(oz,y,ox) = data(x,y,z);
+				}
+			}
+		}
+		break;
+	}
+	case rotate_y270:{
+		// rotate around y-axis by 90 degree clock wise
+		C3DBounds out_size(data.get_size().zyx());
+		result = new T3DImage<T>(out_size, data);
+		result->set_voxel_size(data.get_voxel_size().zyx());
+
+		for (size_t z = 0; z < data.get_size().z; ++z) {
+			for (size_t y = 0; y < data.get_size().y; ++y) {
+				unsigned  ox = data.get_size().x - 1; 
+				for (size_t x = 0; x < data.get_size().x; ++x, --ox) {
+					(*result)(z,y,ox) = data(x,y,z);
+				}
+				
+			}
+		}
+		break;
+	}
+	case rotate_z90:{
+		// rotate around z-axis by 90 degree clock wise
+		
+		C3DBounds out_size(data.get_size().yxz());
+		result = new T3DImage<T>(out_size, data);
+		result->set_voxel_size(data.get_voxel_size().yxz());
+
+		for (size_t z = 0; z < data.get_size().z; ++z) {
+			unsigned  oy = data.get_size().y - 1; 
+			for (size_t y = 0; y < data.get_size().y; ++y, --oy) {
+				for (size_t x = 0; x < data.get_size().x; ++x) {
+					(*result)(oy,x,z) = data(x,y,z);
+				}
+			}
+		}
+		break;
+	}
+	case rotate_z180:{
+		// rotate around y-axis by 180 degree 
+		C3DBounds out_size(data.get_size());
+		result = new T3DImage<T>(out_size, data);
+		result->set_voxel_size(data.get_voxel_size());
+		
+		for (size_t z = 0; z < data.get_size().z; ++z) {
+			unsigned  oy = data.get_size().y - 1; 
+			for (size_t y = 0; y < data.get_size().y; ++y, --oy) {
+				unsigned ox = data.get_size().x - 1; 
+				for (size_t x = 0; x < data.get_size().x; ++x, --ox) {
+					(*result)(oy,ox,z) = data(x,y,z);
+				}
+			}
+		}
+		break;
+	}
+	case rotate_z270:{
+		
+		// rotate around z-axis by 270 degree clock wise
+		C3DBounds out_size(data.get_size().yxz());
+		result = new T3DImage<T>(out_size, data);
+		result->set_voxel_size(data.get_voxel_size().yxz());
+
+		for (size_t z = 0; z < data.get_size().z; ++z) {
+			for (size_t y = 0; y < data.get_size().y; ++y) {
+				unsigned  ox = data.get_size().x - 1; 
+				for (size_t x = 0; x < data.get_size().x; ++x, --ox) {
+					(*result)(y,ox,z) = data(x,y,z);
+				}
+				
+			}
+		}
+		break;
+	}
 	default:
 		throw invalid_argument("Unknown reorientation requested");
 	}
@@ -134,20 +273,15 @@ E3DImageOrientation C3DReorient::get_new_orientation(EOrientations strategy, E3D
 	cvdebug() << "strategy = " << strategy << ", old_orientation: " << old_orientation << "\n";
 	switch (strategy) {
 	case xyz: return old_orientation;
-	case xzy: switch (old_orientation) {
+	case flip_yz: switch (old_orientation) {
 		case ior_axial:    return ior_saggital;
 		case ior_saggital: return ior_axial;
 		case ior_coronal:  return ior_axial;
 		default:
 			return old_orientation;
 		}
-	case yxz:switch (old_orientation) {
-		case ior_axial:    return ior_axial;
-		case ior_saggital: return ior_saggital;
-		case ior_coronal:  return ior_coronal;
-		default:
-			return old_orientation;
-		}
+	case flip_xy:
+		return old_orientation;
 	case yzx:switch (old_orientation) {
 		case ior_axial:    return ior_saggital;
 		case ior_saggital: return ior_coronal;
@@ -162,7 +296,7 @@ E3DImageOrientation C3DReorient::get_new_orientation(EOrientations strategy, E3D
 		default:
 			return old_orientation;
 		}
-	case zyx:
+	case flip_xz:
 		switch (old_orientation) {
 		case ior_axial:    return ior_saggital;
 		case ior_saggital: return ior_coronal;
@@ -170,46 +304,11 @@ E3DImageOrientation C3DReorient::get_new_orientation(EOrientations strategy, E3D
 		default:
 			return old_orientation;
 		}
-	case axial: return ior_axial;
-	case coronal: return ior_coronal;
-	case saggital: return ior_saggital;
 	default:
 		return old_orientation;
 	}
 }
 
-C3DReorient::EOrientations C3DReorient::get_strategy(E3DImageOrientation old_orientation) const
-{
-	TRACE(__FUNCTION__);
-	switch (old_orientation)  {
-	case ior_axial:
-		switch (m_strategy)  {
-		case axial:    return xyz;
-		case saggital: return zyx; //??
-		case coronal:  return xyz; //??
-		default:
-			return xyz;
-		};
-	case ior_saggital:
-		switch (m_strategy)  {
-		case axial:    return zyx;
-		case saggital: return xyz; //??
-		case coronal:  return xyz; //??
-		default:
-			return xyz;
-		};
-	case ior_coronal:
-		switch (m_strategy)  {
-		case axial:    return xyz;
-		case saggital: return zyx; //??
-		case coronal:  return xyz; //??
-		default:
-			return xyz;
-		};
-	default:
-		return xyz;
-	}
-}
 
 /* The actual filter dispatch function calls the filter by selecting the right pixel type through wrap_filter */
 P3DImage C3DReorient::do_filter(const C3DImage& image) const
@@ -241,11 +340,20 @@ const string C3DReorientImageFilterFactory::do_get_descr()const
 const TDictMap<C3DReorient::EOrientations>::Table
 C3DReorientImageFilterFactory::table[] = {
 	{"xyz", C3DReorient::xyz, "keep orientation"},
-	{"xzy", C3DReorient::xzy, "switch y-z" },
-	{"yxz", C3DReorient::yzx, "switch x-y" },
-	{"yzx", C3DReorient::yxz, "rotate x->z->y->x" },
-	{"zxy", C3DReorient::zxy, "rotate x->y->z->x" },
-	{"zyx", C3DReorient::zxy, "switch x-z" },
+	{"f-yz", C3DReorient::flip_yz, "flip y-z" },
+	{"f-xy", C3DReorient::flip_xy, "flip x-y" },
+	{"p-yzx", C3DReorient::yzx, "permutate x->z->y->x" },
+	{"p-zxy", C3DReorient::zxy, "permutate x->y->z->x" },
+	{"f-xz", C3DReorient::flip_xz, "flip x-z" },
+	{"r-x90", C3DReorient::rotate_x90, "rotate around x-axis clockwise 90 degree" },
+	{"r-x180", C3DReorient::rotate_x180, "rotate around x-axis clockwise 180 degree" },
+	{"r-x270", C3DReorient::rotate_x270, "rotate around x-axis clockwise 270 degree" },
+	{"r-y90", C3DReorient::rotate_y90, "rotate around y-axis clockwise 90 degree" },
+	{"r-y180", C3DReorient::rotate_y180, "rotate around y-axis clockwise 180 degree" },
+	{"r-y270", C3DReorient::rotate_y270, "rotate around y-axis clockwise 270 degree" },
+	{"r-z90", C3DReorient::rotate_z90, "rotate around z-axis clockwise 90 degree" },
+	{"r-z180", C3DReorient::rotate_z180, "rotate around z-axis clockwise 180 degree" },
+	{"r-z270", C3DReorient::rotate_z270, "rotate around z-axis clockwise 270 degree" },
 	{NULL,  C3DReorient::ooo, "" },
 };
 const TDictMap<C3DReorient::EOrientations>
