@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -75,7 +75,7 @@ C3DLandmarklist::iterator C3DLandmarklist::end()
 	return m_list.end();
 }
 
-void C3DLandmarklist::set_path(const boost::filesystem::path& path)
+void C3DLandmarklist::set_path(const std::string& path)
 {
 	m_path = path; 
 }
