@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 
 #include <mia/3d/orientation.hh>
 #include <mia/core/utils.hh>
+#include <mia/core/attributes.cxx>
 
 NS_MIA_BEGIN
 using namespace std; 
@@ -313,6 +314,9 @@ EXPORT_3D  std::istream& operator >> (std::istream& is, C3DOrientationAndPositio
 	return is; 
 }
 
+template class  EXPORT_3D TTranslator<E3DImageOrientation>;
+template class  EXPORT_3D TTranslator<E3DPatientPositioning>;
+template class  EXPORT_3D TTranslator<C3DOrientationAndPosition>; 
 
 
 NS_MIA_END
