@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -310,12 +310,12 @@ double C3DPPDivcurlMatrixImpl::multiply(const Field& coefficients) const
 {
 	assert(coefficients.size() == m_nodes); 
 
-	register double result_1 = 0.0; 
-	register double result_2 = 0.0; 
-	register double result_3 = 0.0; 
-	register double result_4 = 0.0; 
-	register double result_5 = 0.0; 
-	register double result_6 = 0.0; 
+	double result_1 = 0.0; 
+	double result_2 = 0.0; 
+	double result_3 = 0.0; 
+	double result_4 = 0.0; 
+	double result_5 = 0.0; 
+	double result_6 = 0.0; 
 
 	const int nx = m_size.x;
 	const int ny = m_size.y;
