@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,12 +36,4 @@ namespace bfs=::boost::filesystem;
 
 BOOST_AUTO_TEST_CASE( test_found_filters )
 {
-	CPathNameArray searchpath;
-	searchpath.push_back( bfs::path("fifof"));
-	C2DFifoFilterPluginHandler::set_search_path(searchpath);
-	BOOST_CHECK_EQUAL(C2DFifoFilterPluginHandler::instance().size(), 10u);
-
-	BOOST_CHECK_EQUAL(C2DFifoFilterPluginHandler::instance().get_plugin_names(),
-			  "byslice close dilate erode gauss label median mlv open regiongrow ");
-
 }
