@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -95,12 +95,12 @@ BOOST_AUTO_TEST_CASE( test_fullcost )
 	CDoubleVector gradient(t.degrees_of_freedom()); 
 	c.set_size(t.get_size()); 
 	
-	BOOST_CHECK_EQUAL(c.evaluate(t,gradient), 0.5 * mcost);
+	BOOST_CHECK_CLOSE(c.evaluate(t,gradient), 0.5 * mcost, 0.01);
 
-	BOOST_CHECK_EQUAL(gradient[0], 0.5 * mgx);
-	BOOST_CHECK_EQUAL(gradient[1], 0.5 * mgy);
+	BOOST_CHECK_CLOSE(gradient[0], 0.5 * mgx, 0.01);
+	BOOST_CHECK_CLOSE(gradient[1], 0.5 * mgy, 0.01);
 
-	BOOST_CHECK_EQUAL(gradient[2], 0.5 * mgz);
+	BOOST_CHECK_CLOSE(gradient[2], 0.5 * mgz, 0.01);
 }
 
 BOOST_AUTO_TEST_CASE( test_multicost ) 
@@ -126,11 +126,11 @@ BOOST_AUTO_TEST_CASE( test_multicost )
 	CDoubleVector gradient(t.degrees_of_freedom()); 
 	costs.set_size(t.get_size()); 
 	
-	BOOST_CHECK_EQUAL(costs.evaluate(t,gradient), 0.5 * mcost1 + 0.2 * mcost2);
+	BOOST_CHECK_CLOSE(costs.evaluate(t,gradient), 0.5 * mcost1 + 0.2 * mcost2, 0.1);
 
-	BOOST_CHECK_EQUAL(gradient[0], 0.5 * mgx1 + 0.2 * mgx2);
-	BOOST_CHECK_EQUAL(gradient[1], 0.5 * mgy1 + 0.2 * mgy2);
-	BOOST_CHECK_EQUAL(gradient[2], 0.5 * mgz1 + 0.2 * mgz2);
+	BOOST_CHECK_CLOSE(gradient[0], 0.5 * mgx1 + 0.2 * mgx2, 0.1);
+	BOOST_CHECK_CLOSE(gradient[1], 0.5 * mgy1 + 0.2 * mgy2, 0.1);
+	BOOST_CHECK_CLOSE(gradient[2], 0.5 * mgz1 + 0.2 * mgz2, 0.1);
 }
 
 
@@ -160,11 +160,11 @@ BOOST_AUTO_TEST_CASE( test_multicost2 )
 	CDoubleVector gradient(t.degrees_of_freedom(), true); 
 	costs.set_size(t.get_size()); 
 	
-	BOOST_CHECK_EQUAL(costs.evaluate(t,gradient), 0.5 * mcost1 + 0.2 * mcost2);
+	BOOST_CHECK_CLOSE(costs.evaluate(t,gradient), 0.5 * mcost1 + 0.2 * mcost2, 0.1);
 
-	BOOST_CHECK_EQUAL(gradient[0], 0.5 * mgx1 + 0.2 * mgx2);
-	BOOST_CHECK_EQUAL(gradient[1], 0.5 * mgy1 + 0.2 * mgy2);
-	BOOST_CHECK_EQUAL(gradient[2], 0.5 * mgz1 + 0.2 * mgz2);
+	BOOST_CHECK_CLOSE(gradient[0], 0.5 * mgx1 + 0.2 * mgx2, 0.1);
+	BOOST_CHECK_CLOSE(gradient[1], 0.5 * mgy1 + 0.2 * mgy2, 0.1);
+	BOOST_CHECK_CLOSE(gradient[2], 0.5 * mgz1 + 0.2 * mgz2, 0.1);
 }
 
 
@@ -408,17 +408,5 @@ const C3DTransformCreatorHandler::Instance& PrepareFullcostTests::transform_hand
 
 PrepareFullcostTests::PrepareFullcostTests()
 {
-	CPathNameArray cost_kernel_plugpath;
-	cost_kernel_plugpath.push_back(bfs::path("cost"));
-	C3DImageCostPluginHandler::set_search_path(cost_kernel_plugpath);
-	
-	CPathNameArray cost_plugpath;
-	cost_plugpath.push_back(bfs::path("fullcost"));
-	C3DFullCostPluginHandler::set_search_path(cost_plugpath);
-
-	CPathNameArray transform_searchpath;
-	transform_searchpath.push_back(bfs::path("transform"));
-	C3DTransformCreatorHandler::set_search_path(transform_searchpath);
-
 }
 
