@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -118,14 +118,6 @@ const C3DTransformCreatorHandler::Instance& PrepareTransIOTests::transform_handl
 
 PrepareTransIOTests::PrepareTransIOTests()
 {
-	CPathNameArray transformio_plugpath;
-	transformio_plugpath.push_back(bfs::path("transio"));
-	C3DTransformationIOPluginHandler::set_search_path(transformio_plugpath);
-	
-	CPathNameArray transform_searchpath;
-	transform_searchpath.push_back(bfs::path("transform"));
-	C3DTransformCreatorHandler::set_search_path(transform_searchpath);
-
 }
 
 
