@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 
 
 #include <mia/3d/vectorfield.hh>
+
 #include <mia/3d/datafield.cxx>
 #include <mia/2d/datafield.cxx>
 #include <mia/3d/iterator.cxx>
@@ -55,17 +56,18 @@ EXPORT_3D C3DFVectorfield& operator += (C3DFVectorfield& a, const C3DFVectorfiel
 	return a;
 }
 
-#define INSTANCIATE(TYPE) \
-	template class  T3DDatafield<TYPE>;			\
+#define INSTANCIATE(TYPE)						\
+	template class  T3DDatafield<TYPE>;				\
 	template class  range3d_iterator<T3DDatafield<TYPE>::iterator>; \
 	template class  range3d_iterator<T3DDatafield<TYPE>::const_iterator>; \
 	template class  range3d_iterator_with_boundary_flag<T3DDatafield<TYPE>::iterator>; \
 	template class  range3d_iterator_with_boundary_flag<T3DDatafield<TYPE>::const_iterator>; 
 
+
 #define INSTANCIATE2D(TYPE)						\
 	template class  EXPORT_3D T2DDatafield<TYPE>;			\
-	template class  EXPORT_3D range2d_iterator<T2DDatafield<TYPE>::iterator>; \
-	template class  EXPORT_3D range2d_iterator<T2DDatafield<TYPE>::const_iterator>;
+	template class  range2d_iterator<T2DDatafield<TYPE>::iterator>; \
+	template class  range2d_iterator<T2DDatafield<TYPE>::const_iterator>;
 
 
 INSTANCIATE2D(C3DFVector); 
