@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,11 +64,11 @@ void CCmdStringOption::do_write_value(std::ostream& os) const
 		os << "=" << m_value;
 }
 
-void CCmdStringOption::do_get_long_help_xml(std::ostream& os, xmlpp::Element& parent, HandlerHelpMap& handler_map) const
+void CCmdStringOption::do_get_long_help_xml(std::ostream& os, CXMLElement& parent, HandlerHelpMap& handler_map) const
 {
 	if (m_plugin_hint) {
 		m_plugin_hint->add_dependend_handlers(handler_map); 
-		m_plugin_hint->get_string_help_description_xml(os, &parent); 
+		m_plugin_hint->get_string_help_description_xml(os, parent); 
 	}else
 		parent.set_attribute("type", __type_descr<string>::value);
 }
