@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ const char *spacial_kernel_data::data_descr = "1d";
 const char *kernel_plugin_type::type_descr = "spacialkernel";
 
 
-C1DFilterKernel::C1DFilterKernel(int fsize):
+C1DFilterKernel::C1DFilterKernel(unsigned fsize):
 	m_fsize(fsize)
 {
 }
