@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,8 +41,9 @@ struct DummyPluginFixture {
 
 DummyPluginFixture::DummyPluginFixture()
 {
-	TRACE_FUNCTION; 
-	CPathNameArray sp{bfs::path("testplug")}; 
+	TRACE_FUNCTION;
+	CPluginSearchpath sp(true);
+	sp.add("testplug"); 
 	CTestIOPluginHandler::set_search_path(sp);
 }
 
