@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,54 +39,24 @@ using namespace std;
 BOOST_AUTO_TEST_CASE( test_params )
 {
 
-	int int_val = 1;
-	float float_val = 2.1;
 	bool bool_val = false;
 	string string_val("initial");
 	string sval("replaced");
 
-	CIntParameter   param_int(int_val, -2, 5, true, "an integer value");
-	CFloatParameter param_float(float_val, -10, 200, true, "a float value");
 	CStringParameter param_string(string_val, CCmdOptionFlags::required, "a string value");
 	CBoolParameter   param_bool(bool_val, false, "a bool value");
 
-	BOOST_CHECK_THROW( CIntParameter(int_val, 5, -2, false, "impossible"), std::invalid_argument);
-
-	BOOST_CHECK(param_int.required_set());
 	BOOST_CHECK(!param_bool.required_set());
 
-	param_int.set("3");
-	param_float.set("3.12");
 	param_string.set(sval);
 	param_bool.set("1");
-
-	BOOST_CHECK(!param_int.required_set());
-	BOOST_CHECK(!param_float.required_set());
 	BOOST_CHECK(!param_string.required_set());
 
-	BOOST_CHECK(int_val == 3);
-	BOOST_CHECK_CLOSE(float_val, 3.12f, 1e-10);
+
 
 	BOOST_CHECK(string_val == sval);
 	BOOST_CHECK(bool_val);
 
-	// check boundary adjustment
-	param_int.set("7");
-	BOOST_CHECK(int_val == 5);
-
-	param_int.set("-3");
-	BOOST_CHECK(int_val == -2);
-
-	param_float.set("-20");
-	BOOST_CHECK(float_val == -10.f);
-
-	param_float.set("300");
-	BOOST_CHECK(float_val == 200.f);
-
-	BOOST_CHECK_THROW( param_float.set("bla"), std::invalid_argument);
-
-	BOOST_CHECK_THROW( param_int.set("1.1"), std::invalid_argument);
-	BOOST_CHECK_NO_THROW( param_int.set("1 "));
 }
 
 enum ETest {te_unknown, te_a, te_b, te_c};
@@ -141,7 +111,7 @@ BOOST_AUTO_TEST_CASE( test_set_params)
 
 	BOOST_CHECK_THROW(testp1.set("3"), std::invalid_argument);
 
-	BOOST_CHECK_THROW(!testp1.set("gjhgjhdf"), std::invalid_argument);
+	BOOST_CHECK_THROW(testp1.set("gjhgjhdf"), std::invalid_argument);
 }
 
 BOOST_AUTO_TEST_CASE( test_vector_param)
@@ -159,5 +129,113 @@ BOOST_AUTO_TEST_CASE( test_vector_param)
 }
 
 
+BOOST_AUTO_TEST_CASE( test_bounded_param_float_closed)
+{
+	float v = 0.0; 
+	CFBoundedParameter testv(v, EParameterBounds::bf_closed_interval, 
+				 {2.0, 4.0}, false, "a bounded test value"); 
+	
+	
+	BOOST_CHECK(testv.set("2.5"));
+	BOOST_CHECK_EQUAL(v, 2.5);
+	
+	BOOST_CHECK(testv.set("4.0"));
+	BOOST_CHECK_EQUAL(v, 4.0);
+
+	BOOST_CHECK(testv.set("2.0"));
+	BOOST_CHECK_EQUAL(v, 2.0);
+	
+
+	BOOST_CHECK_THROW(testv.set("1.0"), std::invalid_argument);
+	BOOST_CHECK_THROW(testv.set("5.0"), std::invalid_argument);
+}
+
+BOOST_AUTO_TEST_CASE( test_bounded_param_float_open)
+{
+	float v = 0.0; 
+	CFBoundedParameter testv(v, EParameterBounds::bf_open_interval, 
+				 {2.0, 4.0}, false, "a bounded test value"); 
+	
+	
+	BOOST_CHECK(testv.set("2.5"));
+	BOOST_CHECK_EQUAL(v, 2.5);
+	
+	BOOST_CHECK_THROW(testv.set("4.0"), std::invalid_argument); 
+	BOOST_CHECK_THROW(testv.set("2.0"), std::invalid_argument);
+	BOOST_CHECK_THROW(testv.set("1.0"), std::invalid_argument);
+	BOOST_CHECK_THROW(testv.set("5.0"), std::invalid_argument);
+}
+
+BOOST_AUTO_TEST_CASE( test_bounded_param_int_min_open)
+{
+	int v = 0; 
+	CSIBoundedParameter testv(v, EParameterBounds::bf_min_open, 
+				  {-2}, false, "a bounded test value"); 
+	
+	
+	BOOST_CHECK(testv.set("-1"));
+	BOOST_CHECK_EQUAL(v, -1);
+	
+	BOOST_CHECK_THROW(testv.set("-2"), std::invalid_argument); 
+	BOOST_CHECK_THROW(testv.set("-3"), std::invalid_argument); 
+}
+
+BOOST_AUTO_TEST_CASE( test_bounded_param_int_min_close)
+{
+	int v = 0; 
+	CSIBoundedParameter testv(v, EParameterBounds::bf_min_closed, 
+				  {-2}, false, "a bounded test value"); 
+	
+	
+	BOOST_CHECK(testv.set("-2"));
+	BOOST_CHECK_EQUAL(v, -2);
+
+	BOOST_CHECK(testv.set("2"));
+	BOOST_CHECK_EQUAL(v, 2);
+	
+	BOOST_CHECK_THROW(testv.set("-3"), std::invalid_argument); 
+}
+
+
+BOOST_AUTO_TEST_CASE( test_bounded_param_unsignedshort_min_open)
+{
+	unsigned short v = 0; 
+	CUSBoundedParameter testv(v, EParameterBounds::bf_min_open, 
+				  {2}, false, "a bounded test value"); 
+	
+	
+	BOOST_CHECK(testv.set("3"));
+	BOOST_CHECK_EQUAL(v, 3);
+	
+	BOOST_CHECK_THROW(testv.set("2"), std::invalid_argument); 
+	BOOST_CHECK_THROW(testv.set("1"), std::invalid_argument); 
+}
+
+BOOST_AUTO_TEST_CASE( test_bounded_param_unsignedshort_min_close)
+{
+	unsigned short v = 0; 
+	CUSBoundedParameter testv(v, EParameterBounds::bf_min_closed, 
+				  {2}, false, "a bounded test value"); 
+	
+	
+	BOOST_CHECK(testv.set("2"));
+	BOOST_CHECK_EQUAL(v, 2);
+
+	BOOST_CHECK(testv.set(" 3"));
+	BOOST_CHECK_EQUAL(v, 3);
+	
+	BOOST_CHECK_THROW(testv.set("1"), std::invalid_argument); 
+}
+
+BOOST_AUTO_TEST_CASE( test_bounded_param_unsignedshort_min_close_negative_input)
+{
+	unsigned short v = 0; 
+	CUSBoundedParameter testv(v, EParameterBounds::bf_min_closed, 
+				  {2}, false, "a bounded test value"); 
+	
+	BOOST_CHECK_THROW(testv.set(" -1"), std::invalid_argument); 
+}
+
+
 
 
