@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -104,8 +104,7 @@ TFullCostPlugin<T>::TFullCostPlugin(const char *name):
 	TFactory<TFullCost<T> >(name), 
 	m_weight(1.0)
 {
-	this->add_parameter("weight", new CFloatParameter(m_weight, -1e+10f, 1e+10f,
-						    false, "weight of cost function"));
+	this->add_parameter("weight", new CTParameter<float>(m_weight, false, "weight of cost function"));
 }
 	
 template <typename T> 
